@@ -16,7 +16,7 @@ class RedisPool(BaseConnectionPool):
         """
         try:
             aioredis = importlib.import_module("aioredis")
-        except ImportError as e:
+        except ImportError:
             raise Exception(f"aioredis is not exist,run:pip install aioredis==2.0.1")
         if self.conn_info.async_enable:
             pool = aioredis.ConnectionPool.from_url(f"redis://{self.conn_info.host}", port=self.conn_info.port,
@@ -29,7 +29,7 @@ class RedisPool(BaseConnectionPool):
     def sync_create_pool(self):
         try:
             redis = importlib.import_module("redis")
-        except ImportError as e:
+        except ImportError:
             raise Exception(f"redis is not exist,run:pip install redis==4.1.4")
         pool = redis.ConnectionPool.from_url(f"redis://{self.conn_info.host}", port=self.conn_info.port,
                                              password=self.conn_info.password,
