@@ -2,15 +2,14 @@ import base64
 import binascii
 import importlib
 
-try:
-    Des = importlib.import_module("Cryptodome.Cipher.DES")
-except ImportError as e:
-    raise Exception(f"pycryptodomex is not exist,run:pip install pycryptodomex==3.17")
-
 
 class DES:
     @staticmethod
-    def encrypt(text: str, key: str, mode=Des.MODE_ECB):
+    def encrypt(text: str, key: str, mode=1):
+        try:
+            Des = importlib.import_module("Cryptodome.Cipher.DES")
+        except ImportError as e:
+            raise Exception(f"pycryptodomex is not exist,run:pip install pycryptodomex==3.17")
         text = str(text)
         des = Des.new(DES.pad(key), mode)
         encrypt_aes = des.encrypt(DES.pad(text))
@@ -18,7 +17,11 @@ class DES:
         return bytes.decode(binascii.b2a_hex(bytes(encrypted_text, encoding="utf8")))
 
     @staticmethod
-    def decrypt(text: str, key: str, mode=Des.MODE_ECB):
+    def decrypt(text: str, key: str, mode=1):
+        try:
+            Des = importlib.import_module("Cryptodome.Cipher.DES")
+        except ImportError as e:
+            raise Exception(f"pycryptodomex is not exist,run:pip install pycryptodomex==3.17")
         text = bytes.decode(binascii.a2b_hex(bytes(text, encoding="utf8")))
         des = Des.new(DES.pad(key), mode)
         base64_decrypted = base64.decodebytes(text.encode(encoding='utf-8'))
