@@ -1,4 +1,5 @@
 import json
+import math
 
 
 class JSONEncoder(json.JSONEncoder):
@@ -14,4 +15,10 @@ class JSONEncoder(json.JSONEncoder):
             return list(o)
         elif object_class_name == "Decimal":
             return str(o)
+        elif object_class_name == "ndarray":
+            return o.tolist()
+        elif object_class_name == "Series":
+            return o.tolist()
+        elif object_class_name == "DataFrame":
+            return o.to_dict(orient='records')
         return json.JSONEncoder.default(self, o)
